@@ -1,10 +1,11 @@
 import argparse
+import sys
 
-from incase.classes import Case, Caseless
-from incase.functions import case_modifier, incase, planetary_defense_shield
+from incase.core import Case, Caseless
+from incase.extra import case_modifier, incase, planetary_defense_shield
 
 
-def cli():
+def parse_args(args):
     parser = argparse.ArgumentParser(
         description="Convert a word from one case to another."
     )
@@ -19,9 +20,13 @@ def cli():
         help="The desired case to transform to.",
     )
 
-    args = parser.parse_args()
+    return parser.parse_args(args)
+
+
+def cli():
+    args = parse_args(sys.argv[1:])
     for word in args.words:
         print(incase(args.case, word))
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     cli()
